==> jc-1.4.0.tar.gz: javax/swing/text/LayeredHighlighter.h <==
// public abstract class javax.swing.text.LayeredHighlighter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8004061994ba9184 javax_swing_text_LayeredHighlighter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_LayeredHighlighter_H_
#define _JC_javax_swing_text_LayeredHighlighter_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_JTextComponent$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_text_LayeredHighlighter$sub_refs	_jc_javax_swing_text_LayeredHighlighter$sub_refs;
typedef struct _jc_javax_swing_text_LayeredHighlighter$sub_nonrefs	_jc_javax_swing_text_LayeredHighlighter$sub_nonrefs;
typedef struct _jc_javax_swing_text_LayeredHighlighter$refs	_jc_javax_swing_text_LayeredHighlighter$refs;
typedef struct _jc_javax_swing_text_LayeredHighlighter$nonrefs	_jc_javax_swing_text_LayeredHighlighter$nonrefs;
typedef struct _jc_javax_swing_text_LayeredHighlighter$object	_jc_javax_swing_text_LayeredHighlighter$object;

typedef const struct _jc_javax_swing_text_LayeredHighlighter$vmethods	_jc_javax_swing_text_LayeredHighlighter$vmethods;
typedef const struct _jc_javax_swing_text_LayeredHighlighter$vtable	_jc_javax_swing_text_LayeredHighlighter$vtable;
typedef const struct _jc_javax_swing_text_LayeredHighlighter$vtype	_jc_javax_swing_text_LayeredHighlighter$vtype;

// Constructors
extern void _jc_javax_swing_text_LayeredHighlighter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_LayeredHighlighter$object *);

// Virtual methods
extern void _jc_javax_swing_text_LayeredHighlighter$method$paintLayeredHighlights$4add603820b16943(_jc_env *, struct _jc_javax_swing_text_LayeredHighlighter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_javax_swing_text_View$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_LayeredHighlighter$method_info$paintLayeredHighlights$4add603820b16943;

// Virtual methods structure
struct _jc_javax_swing_text_LayeredHighlighter$vmethods {
	void	(*paintLayeredHighlights$4add603820b16943)(_jc_env *, struct _jc_javax_swing_text_LayeredHighlighter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_javax_swing_text_View$object *);
};

// Vtable
struct _jc_javax_swing_text_LayeredHighlighter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_LayeredHighlighter$vmethods	javax_swing_text_LayeredHighlighter;
};

// Vtype
struct _jc_javax_swing_text_LayeredHighlighter$vtype {
	_jc_type			type;
	_jc_javax_swing_text_LayeredHighlighter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_LayeredHighlighter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_LayeredHighlighter$refs {
    _jc_javax_swing_text_LayeredHighlighter$sub_refs	javax_swing_text_LayeredHighlighter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_LayeredHighlighter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_LayeredHighlighter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_LayeredHighlighter$sub_nonrefs	javax_swing_text_LayeredHighlighter;
};

// Object instance structure
struct _jc_javax_swing_text_LayeredHighlighter$object {
	_jc_javax_swing_text_LayeredHighlighter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_LayeredHighlighter$vtype	*vtype;
	_jc_javax_swing_text_LayeredHighlighter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_LayeredHighlighter$vtype _jc_javax_swing_text_LayeredHighlighter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_LayeredHighlighter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_LayeredHighlighter$class_object;

#endif	/* _JC_javax_swing_text_LayeredHighlighter_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/LayeredHighlighter.h <==
// public abstract class javax.swing.text.LayeredHighlighter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8004061994ba9184 javax_swing_text_LayeredHighlighter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_LayeredHighlighter_H_
#define _JC_javax_swing_text_LayeredHighlighter_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_JTextComponent$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_text_LayeredHighlighter$sub_refs	_jc_javax_swing_text_LayeredHighlighter$sub_refs;
typedef struct _jc_javax_swing_text_LayeredHighlighter$sub_nonrefs	_jc_javax_swing_text_LayeredHighlighter$sub_nonrefs;
typedef struct _jc_javax_swing_text_LayeredHighlighter$refs	_jc_javax_swing_text_LayeredHighlighter$refs;
typedef struct _jc_javax_swing_text_LayeredHighlighter$nonrefs	_jc_javax_swing_text_LayeredHighlighter$nonrefs;
typedef struct _jc_javax_swing_text_LayeredHighlighter$object	_jc_javax_swing_text_LayeredHighlighter$object;

typedef const struct _jc_javax_swing_text_LayeredHighlighter$vmethods	_jc_javax_swing_text_LayeredHighlighter$vmethods;
typedef const struct _jc_javax_swing_text_LayeredHighlighter$vtable	_jc_javax_swing_text_LayeredHighlighter$vtable;
typedef const struct _jc_javax_swing_text_LayeredHighlighter$vtype	_jc_javax_swing_text_LayeredHighlighter$vtype;

// Constructors
extern void _jc_javax_swing_text_LayeredHighlighter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_LayeredHighlighter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_LayeredHighlighter$method$paintLayeredHighlights$4add603820b16943(_jc_env *, struct _jc_javax_swing_text_LayeredHighlighter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_javax_swing_text_View$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_LayeredHighlighter$method_info$paintLayeredHighlights$4add603820b16943;

// Virtual methods structure
struct _jc_javax_swing_text_LayeredHighlighter$vmethods {
	void	(*paintLayeredHighlights$4add603820b16943)(_jc_env *, struct _jc_javax_swing_text_LayeredHighlighter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_javax_swing_text_View$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_LayeredHighlighter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_LayeredHighlighter$vmethods	javax_swing_text_LayeredHighlighter;
};

// Vtype
struct _jc_javax_swing_text_LayeredHighlighter$vtype {
	_jc_type			type;
	_jc_javax_swing_text_LayeredHighlighter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_LayeredHighlighter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_LayeredHighlighter$refs {
    _jc_javax_swing_text_LayeredHighlighter$sub_refs	javax_swing_text_LayeredHighlighter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_LayeredHighlighter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_LayeredHighlighter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_LayeredHighlighter$sub_nonrefs	javax_swing_text_LayeredHighlighter;
};

// Object instance structure
struct _jc_javax_swing_text_LayeredHighlighter$object {
	_jc_javax_swing_text_LayeredHighlighter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_LayeredHighlighter$vtype	*vtype;
	_jc_javax_swing_text_LayeredHighlighter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_LayeredHighlighter$vtype _jc_javax_swing_text_LayeredHighlighter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_LayeredHighlighter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_LayeredHighlighter$class_object;

#endif	/* _JC_javax_swing_text_LayeredHighlighter_H_ */
